=== modified file 'NEWS'
--- NEWS	2007-02-08 12:33:13 +0000
+++ NEWS	2007-02-08 17:01:20 +0000
@@ -76,9 +76,9 @@
       the ``--use-existing-dir`` flag.
       (John Arbash Meinel, #30576, #45504)
 
-    * Lack of http authorization support in test framework, a
-      typo in prroxy handling have been unnoticed. (Vincent
-      Ladeuil, #83954).
+    * Fix http proxy authentication when user and an optional
+      password appears in the *_proxy vars. (Vincent Ladeuil,
+      #83954).
 
   TESTING:
 

=== modified file 'bzrlib/tests/test_http.py'
--- bzrlib/tests/test_http.py	2007-02-08 12:33:13 +0000
+++ bzrlib/tests/test_http.py	2007-02-08 17:01:20 +0000
@@ -636,6 +636,57 @@
     """Tests range requests refusing server for pycurl implementation"""
 
 
+class TestHttpProxyWhiteBox(TestCase):
+    """Whitebox test proxy http authorization."""
+
+    def setUp(self):
+        TestCase.setUp(self)
+        self._old_env = {}
+
+    def tearDown(self):
+        self._restore_env()
+
+    def _set_and_capture_env_var(self, name, new_value):
+        """Set an environment variable, and reset it when finished."""
+        self._old_env[name] = osutils.set_or_unset_env(name, new_value)
+
+    def _install_env(self, env):
+        for name, value in env.iteritems():
+            self._set_and_capture_env_var(name, value)
+
+    def _restore_env(self):
+        for name, value in self._old_env.iteritems():
+            osutils.set_or_unset_env(name, value)
+
+    def _proxied_request(self):
+        from bzrlib.transport.http._urllib2_wrappers import (
+            ProxyHandler,
+            Request,
+            )
+
+        handler = ProxyHandler()
+        request = Request('GET','http://baz/buzzle')
+        handler.set_proxy(request, 'http')
+        return request
+
+    def test_empty_user(self):
+        self._install_env({'http_proxy': 'http://bar.com'})
+        request = self._proxied_request()
+        self.assertFalse(request.headers.has_key('Proxy-authorization'))
+
+    def test_empty_pass(self):
+        self._install_env({'http_proxy': 'http://joe@bar.com'})
+        request = self._proxied_request()
+        self.assertEqual('Basic ' + 'joe:'.encode('base64').strip(),
+                         request.headers['Proxy-authorization'])
+    def test_user_pass(self):
+        self._install_env({'http_proxy': 'http://joe:foo@bar.com'})
+        request = self._proxied_request()
+        self.assertEqual('Basic ' + 'joe:foo'.encode('base64').strip(),
+                         request.headers['Proxy-authorization'])
+
+
+
 class TestProxyHttpServer(object):
     """Tests proxy server.
 

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2007-02-08 12:33:13 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2007-02-08 17:01:20 +0000
@@ -708,14 +708,17 @@
             user_pass, host = host.split('@', 1)
             if ':' in user_pass:
                 user, password = user_pass.split(':', 1)
-                user_pass = '%s:%s' % (urllib.unquote(user),
-                               urllib.unquote(password))
-                user_pass.encode('base64').strip()
-                request.add_header('Proxy-authorization', 'Basic ' + user_pass)
+            else:
+                user = user_pass
+                password = ''
+            user_pass = '%s:%s' % (urllib.unquote(user),
+                                   urllib.unquote(password))
+            user_pass = user_pass.encode('base64').strip()
+            request.add_header('Proxy-authorization', 'Basic ' + user_pass)
         host = urllib.unquote(host)
         request.set_proxy(host, type)
         if self._debuglevel > 0:
-            print 'set_proxy: proxy set to %r://%r' % (type, host)
+            print 'set_proxy: proxy set to %s://%s' % (type, host)
         return request
 
 

